# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Representations.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import CommonTypes_pb2 as CommonTypes__pb2
from . import Framework_Representations_pb2 as Framework__Representations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Representations.proto',
  package='naothmessages',
  syntax='proto2',
  serialized_pb=_b('\n\x15Representations.proto\x12\rnaothmessages\x1a\x11\x43ommonTypes.proto\x1a\x1f\x46ramework-Representations.proto\"\x88\x01\n\x0c\x43\x61meraMatrix\x12#\n\x04pose\x18\x01 \x02(\x0b\x32\x15.naothmessages.Pose3D\x12\x31\n\x08\x63\x61meraID\x18\x02 \x01(\x0e\x32\x17.naothmessages.CameraID:\x06\x62ottom\x12\r\n\x05valid\x18\x03 \x01(\x08\x12\x11\n\ttimestamp\x18\x04 \x01(\r\"\x94\x02\n\x0b\x42\x61llPercept\x12\x13\n\x0b\x62\x61llWasSeen\x18\x01 \x01(\x08\x12\x33\n\rcenterInImage\x18\x02 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x15\n\rradiusInImage\x18\x03 \x01(\x01\x12\'\n\tballColor\x18\x04 \x01(\x0e\x32\x14.naothmessages.Color\x12?\n\x19\x62\x65\x61ringBasedOffsetOnField\x18\x05 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12:\n\x18\x66rameInfoWhenBallWasSeen\x18\x06 \x01(\x0b\x32\x18.naothmessages.FrameInfo\"\xcb\x02\n\x10MultiBallPercept\x12:\n\x18\x66rameInfoWhenBallWasSeen\x18\x01 \x01(\x0b\x32\x18.naothmessages.FrameInfo\x12=\n\x08percepts\x18\x02 \x03(\x0b\x32+.naothmessages.MultiBallPercept.BallPercept\x1a\xbb\x01\n\x0b\x42\x61llPercept\x12\x33\n\rcenterInImage\x18\x01 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x15\n\rradiusInImage\x18\x02 \x01(\x01\x12\x35\n\x0fpositionOnField\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12)\n\x08\x63\x61meraId\x18\x04 \x01(\x0e\x32\x17.naothmessages.CameraID\"\xf3\x02\n\tBallModel\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\r\n\x05knows\x18\x02 \x01(\x08\x12.\n\x08position\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12+\n\x05speed\x18\x04 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x35\n\x0fpositionPreview\x18\x05 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12<\n\x16positionPreviewInLFoot\x18\x06 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12<\n\x16positionPreviewInRFoot\x18\x07 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x38\n\x0e\x66uturePosition\x18\x08 \x03(\x0b\x32\x1c.naothmessages.DoubleVector2B\x02\x18\x01\"\xdc\x03\n\x0bGoalPercept\x12\x17\n\x0f\x61ngleToSeenGoal\x18\x01 \x01(\x01\x12\x32\n\x0cgoalCentroid\x18\x02 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x19\n\x11numberOfSeenPosts\x18\x03 \x01(\x05\x12\x31\n\x04post\x18\x04 \x03(\x0b\x32#.naothmessages.GoalPercept.GoalPost\x1a\xb1\x02\n\x08GoalPost\x12,\n\tbasePoint\x18\x01 \x01(\x0b\x32\x19.naothmessages.IntVector2\x12.\n\x08position\x18\x02 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12#\n\x05\x63olor\x18\x03 \x01(\x0e\x32\x14.naothmessages.Color\x12:\n\x04type\x18\x04 \x01(\x0e\x32,.naothmessages.GoalPercept.GoalPost.PostType\x12\x18\n\x10positionReliable\x18\x05 \x01(\x08\x12\x12\n\nseenHeight\x18\x06 \x01(\x01\"8\n\x08PostType\x12\r\n\trightPost\x10\x00\x12\x0c\n\x08leftPost\x10\x01\x12\x0f\n\x0bunknownPost\x10\x02\"\xc6\x03\n\x11HeadMotionRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x10\n\x08\x63\x61meraID\x18\x02 \x02(\r\x12\x39\n\x13targetJointPosition\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x38\n\x12targetPointInImage\x18\x04 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12;\n\x15targetPointInTheWorld\x18\x05 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x32\n\x0csearchCenter\x18\x06 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x30\n\nsearchSize\x18\x07 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x17\n\x0fsearchDirection\x18\x08 \x01(\x08\x12<\n\x16targetPointOnTheGround\x18\t \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x12\n\ncoordinate\x18\n \x01(\r\x12\x10\n\x08velocity\x18\x0b \x01(\x01\"\xa5\x03\n\x12StepControlRequest\x12\x0e\n\x06stepID\x18\x01 \x02(\r\x12\x14\n\x0cmoveLeftFoot\x18\x02 \x02(\x08\x12%\n\x06target\x18\x03 \x02(\x0b\x32\x15.naothmessages.Pose2D\x12\x0c\n\x04time\x18\x04 \x02(\r\x12\x16\n\x0espeedDirection\x18\x05 \x02(\x01\x12\r\n\x05scale\x18\x06 \x02(\x01\x12<\n\x08steptype\x18\x07 \x02(\x0e\x32*.naothmessages.StepControlRequest.StepType\x12\x46\n\x0brestriction\x18\x08 \x02(\x0e\x32\x31.naothmessages.StepControlRequest.RestrictionMode\x12\x13\n\x0bisProtected\x18\t \x02(\x08\x12\x15\n\rstepRequestID\x18\n \x02(\r\"4\n\x08StepType\x12\x0c\n\x08WALKSTEP\x10\x00\x12\x0c\n\x08KICKSTEP\x10\x01\x12\x0c\n\x08ZEROSTEP\x10\x02\"%\n\x0fRestrictionMode\x12\x08\n\x04HARD\x10\x00\x12\x08\n\x04SOFT\x10\x01\"\xba\x01\n\x0bWalkRequest\x12\x12\n\ncoordinate\x18\x01 \x02(\r\x12\x11\n\tcharacter\x18\x02 \x02(\x01\x12%\n\x06target\x18\x03 \x02(\x0b\x32\x15.naothmessages.Pose2D\x12\x36\n\x0bstepControl\x18\x04 \x01(\x0b\x32!.naothmessages.StepControlRequest\x12%\n\x06offset\x18\x05 \x02(\x0b\x32\x15.naothmessages.Pose2D\"{\n\x0bKickRequest\x12/\n\tkickPoint\x18\x01 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x15\n\rkickDirection\x18\x02 \x02(\x01\x12\x10\n\x08kickFoot\x18\x03 \x02(\x05\x12\x12\n\nfinishKick\x18\x04 \x02(\x08\"\x8b\x01\n\x0cGraspRequest\x12\x33\n\rgraspingPoint\x18\x01 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x15\n\rgraspingState\x18\x02 \x02(\r\x12\x16\n\x0egraspDistState\x18\x03 \x02(\r\x12\x17\n\x0fgraspStiffState\x18\x04 \x02(\r\"\xde\x03\n\x10\x41rmMotionRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x37\n\x11lShoulderPosition\x18\x02 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x38\n\x12lShoulderStiffness\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x34\n\x0elElbowPosition\x18\x04 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x35\n\x0flElbowStiffness\x18\x05 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x37\n\x11rShoulderPosition\x18\x06 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x38\n\x12rShoulderStiffness\x18\x07 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x34\n\x0erElbowPosition\x18\x08 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x35\n\x0frElbowStiffness\x18\t \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\"\x97\x03\n\rMotionRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0c\n\x04time\x18\x02 \x02(\r\x12\x0e\n\x06\x66orced\x18\x03 \x02(\x08\x12/\n\x0bwalkRequest\x18\x04 \x01(\x0b\x32\x1a.naothmessages.WalkRequest\x12\x16\n\x0estarndardStand\x18\x05 \x01(\x08\x12/\n\x0bkickRequest\x18\x06 \x01(\x0b\x32\x1a.naothmessages.KickRequest\x12\x13\n\x0bstandHeight\x18\x07 \x01(\x01\x12\"\n\x1a\x63\x61librateFootTouchDetector\x18\x08 \x01(\x08\x12\x1c\n\x14\x63ognitionFrameNumber\x18\t \x01(\r\x12\x31\n\x0cgraspRequest\x18\n \x01(\x0b\x32\x1b.naothmessages.GraspRequest\x12\x39\n\x10\x61rmMotionRequest\x18\x0b \x01(\x0b\x32\x1f.naothmessages.ArmMotionRequest\x12\x1d\n\x15\x64isable_relaxed_stand\x18\x0c \x01(\x08\"\x9a\x06\n\x0bLinePercept\x12:\n\x05lines\x18\x01 \x03(\x0b\x32+.naothmessages.LinePercept.FieldLineSegment\x12>\n\rintersections\x18\x02 \x03(\x0b\x32\'.naothmessages.LinePercept.Intersection\x12\x38\n\x12middleCircleCenter\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x1a\xeb\x02\n\x0cIntersection\x12\x30\n\nposInImage\x18\x01 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x30\n\nposOnField\x18\x02 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x46\n\x04type\x18\x03 \x01(\x0e\x32\x38.naothmessages.LinePercept.Intersection.IntersectionType\x12\x17\n\x0fsegmentOneIndex\x18\x06 \x01(\r\x12\x17\n\x0fsegmentTwoIndex\x18\x07 \x01(\r\x12\x1a\n\x12segmentOneDistance\x18\x08 \x01(\x01\x12\x1a\n\x12segmentTwoDistance\x18\t \x01(\x01\"E\n\x10IntersectionType\x12\x0b\n\x07unknown\x10\x00\x12\x05\n\x01T\x10\x01\x12\x05\n\x01L\x10\x02\x12\x05\n\x01\x43\x10\x03\x12\x08\n\x04none\x10\x04\x12\x05\n\x01X\x10\x05\x1a\xe6\x01\n\x10\x46ieldLineSegment\x12/\n\x0blineInImage\x18\x01 \x01(\x0b\x32\x1a.naothmessages.LineSegment\x12/\n\x0blineOnField\x18\x02 \x01(\x0b\x32\x1a.naothmessages.LineSegment\x12\x18\n\x10\x62\x65ginExtendCount\x18\x03 \x01(\x05\x12\x16\n\x0e\x65ndExtendCount\x18\x04 \x01(\x05\x12\x11\n\tthickness\x18\x05 \x01(\x01\x12\r\n\x05slope\x18\x06 \x01(\x01\x12\r\n\x05\x61ngle\x18\x07 \x01(\x01\x12\r\n\x05valid\x18\x08 \x01(\x08\"I\n\x10ShortLinePercept\x12\x35\n\x11\x66ieldLineSegments\x18\x01 \x03(\x0b\x32\x1a.naothmessages.LineSegment\"4\n\x07Polygon\x12)\n\x06points\x18\x01 \x03(\x0b\x32\x19.naothmessages.IntVector2\"9\n\x0c\x46ieldPercept\x12)\n\tfieldPoly\x18\x01 \x02(\x0b\x32\x16.naothmessages.Polygon\"J\n\x11RansacLinePercept\x12\x35\n\x11\x66ieldLineSegments\x18\x01 \x03(\x0b\x32\x1a.naothmessages.LineSegment\"d\n\x17RansacCirclePercept2018\x12\x0f\n\x07wasSeen\x18\x01 \x01(\x08\x12\x38\n\x12middleCircleCenter\x18\x02 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\"\xac\x01\n\x10ScanLineEndPoint\x12-\n\nposInImage\x18\x01 \x02(\x0b\x32\x19.naothmessages.IntVector2\x12\x30\n\nposOnField\x18\x02 \x02(\x0b\x32\x1c.naothmessages.DoubleVector2\x12#\n\x05\x63olor\x18\x03 \x02(\x0e\x32\x14.naothmessages.Color\x12\x12\n\nScanLineID\x18\x04 \x02(\r\"k\n\x0b\x44oubleEdgel\x12+\n\x05point\x18\x01 \x02(\x0b\x32\x1c.naothmessages.DoubleVector2\x12/\n\tdirection\x18\x02 \x02(\x0b\x32\x1c.naothmessages.DoubleVector2\"b\n\x05\x45\x64gel\x12(\n\x05point\x18\x01 \x02(\x0b\x32\x19.naothmessages.IntVector2\x12/\n\tdirection\x18\x02 \x02(\x0b\x32\x1c.naothmessages.DoubleVector2\"E\n\tEdgelPair\x12\r\n\x05\x62\x65gin\x18\x01 \x02(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x02(\x05\x12\n\n\x02id\x18\x03 \x02(\x05\x12\x10\n\x08\x61\x64\x61ptive\x18\x04 \x01(\x08\"\x99\x01\n\x14ScanLineEdgelPercept\x12$\n\x06\x65\x64gels\x18\x01 \x03(\x0b\x32\x14.naothmessages.Edgel\x12\'\n\x05pairs\x18\x03 \x03(\x0b\x32\x18.naothmessages.EdgelPair\x12\x32\n\tendPoints\x18\x02 \x03(\x0b\x32\x1f.naothmessages.ScanLineEndPoint\"\xa8\x01\n\x10LineGraphPercept\x12+\n\redgelsOnField\x18\x01 \x03(\x0b\x32\x14.naothmessages.Edgel\x12\x34\n\x10\x65\x64gelsInImageTop\x18\x02 \x03(\x0b\x32\x1a.naothmessages.DoubleEdgel\x12\x31\n\redgelsInImage\x18\x03 \x03(\x0b\x32\x1a.naothmessages.DoubleEdgel\"P\n\x11StepControlStatus\x12\x0e\n\x06stepID\x18\x01 \x02(\r\x12\x14\n\x0cmoveableFoot\x18\x02 \x02(\r\x12\x15\n\rstepRequestID\x18\x03 \x02(\r\"\xd2\x03\n\x0cMotionStatus\x12\x0c\n\x04time\x18\x01 \x02(\r\x12\x12\n\nlastMotion\x18\x02 \x02(\r\x12\x15\n\rcurrentMotion\x18\x03 \x02(\r\x12\x12\n\nheadMotion\x18\x04 \x02(\r\x12\x1a\n\x12\x63urrentMotionState\x18\x05 \x02(\r\x12\x34\n\x15plannedMotionLeftFoot\x18\x06 \x02(\x0b\x32\x15.naothmessages.Pose2D\x12\x35\n\x16plannedMotionRightFoot\x18\x07 \x02(\x0b\x32\x15.naothmessages.Pose2D\x12/\n\x10plannedMotionHip\x18\x08 \x02(\x0b\x32\x15.naothmessages.Pose2D\x12;\n\x11stepControlStatus\x18\t \x01(\x0b\x32 .naothmessages.StepControlStatus\x12\x16\n\x0etarget_reached\x18\n \x01(\x08\x12\x1b\n\x13head_target_reached\x18\x0b \x01(\x08\x12\x16\n\x0ehead_got_stuck\x18\x0c \x01(\x08\x12\x1b\n\x13walk_emergency_stop\x18\r \x01(\x08\x12\x14\n\x0chead_at_rest\x18\x0e \x01(\x08\"3\n\x0cOdometryData\x12#\n\x04pose\x18\x01 \x02(\x0b\x32\x15.naothmessages.Pose2D\"\x1f\n\tBodyState\x12\x12\n\nisLiftedUp\x18\x01 \x01(\x08\"3\n\nBodyStatus\x12\x12\n\ncurrentSum\x18\x01 \x03(\x01\x12\x11\n\ttimestamp\x18\x03 \x02(\r\"\xd0\x01\n\x0f\x43\x61librationData\x12:\n\x14inertialSensorOffset\x18\x01 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x36\n\x10gyroSensorOffset\x18\x05 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x35\n\x0f\x61\x63\x63SensorOffset\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x12\n\ncalibrated\x18\x04 \x02(\x08\"B\n\rInertialModel\x12\x31\n\x0borientation\x18\x01 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\"\x88\x02\n\x17\x43\x61meraMatrixCalibration\x12:\n\x10\x63orrectionOffset\x18\x01 \x03(\x0b\x32\x1c.naothmessages.DoubleVector2B\x02\x18\x01\x12:\n\x14\x63orrectionOffsetBody\x18\x02 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12:\n\x14\x63orrectionOffsetHead\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x39\n\x13\x63orrectionOffsetCam\x18\x04 \x03(\x0b\x32\x1c.naothmessages.DoubleVector3\"\x8b\x02\n\x0e\x42\x61llCandidates\x12\x34\n\x07patches\x18\x01 \x03(\x0b\x32#.naothmessages.BallCandidates.Patch\x1a\xc2\x01\n\x05Patch\x12&\n\x03min\x18\x01 \x02(\x0b\x32\x19.naothmessages.IntVector2\x12&\n\x03max\x18\x02 \x02(\x0b\x32\x19.naothmessages.IntVector2\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32(.naothmessages.BallCandidates.Patch.Type:\x01Y\x12\x0c\n\x04\x64\x61ta\x18\x05 \x02(\x0c\" \n\x04Type\x12\x05\n\x01Y\x10\x00\x12\x07\n\x03YUV\x10\x01\x12\x08\n\x04YUVC\x10\x02\"\xf9\x03\n\x14RemoteControlCommand\x12\x44\n\x0b\x63ontrolMode\x18\x01 \x01(\x0e\x32/.naothmessages.RemoteControlCommand.ControlMode\x12>\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32..naothmessages.RemoteControlCommand.ActionType\x12K\n\rsecond_action\x18\x03 \x01(\x0e\x32\x34.naothmessages.RemoteControlCommand.SecondActionType\x12%\n\x06target\x18\x04 \x01(\x0b\x32\x15.naothmessages.Pose2D\"3\n\x0b\x43ontrolMode\x12\x12\n\x0e\x44IRECT_CONTROL\x10\x00\x12\x10\n\x0cLOCK_CONTROL\x10\x01\"y\n\nActionType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05STAND\x10\x01\x12\x08\n\x04WALK\x10\x02\x12\x0e\n\nKICK_RIGHT\x10\x03\x12\r\n\tKICK_LEFT\x10\x04\x12\x15\n\x11KICK_FORWARD_LEFT\x10\x05\x12\x16\n\x12KICK_FORWARD_RIGHT\x10\x06\"7\n\x10SecondActionType\x12\x0f\n\x0bSECOND_NONE\x10\x00\x12\t\n\x05\x42LINK\x10\x01\x12\x07\n\x03SAY\x10\x02\"\xaf\x01\n\x12GroundContactModel\x12\x19\n\x11leftGroundContact\x18\x01 \x02(\x08\x12\x1a\n\x12rightGroundContact\x18\x02 \x02(\x08\x12;\n\x0bsupportFoot\x18\x03 \x02(\x0e\x32&.naothmessages.GroundContactModel.Foot\"%\n\x04\x46oot\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01\x12\x08\n\x04NONE\x10\x02\"\xd5\x01\n\x10\x43ollisionPercept\x12\x1c\n\x14timeCollisionArmLeft\x18\x01 \x02(\r\x12\x1d\n\x15timeCollisionArmRight\x18\x02 \x02(\r\x12\x1d\n\x15isCollisionLeftBumper\x18\x03 \x02(\x08\x12\x1e\n\x16isCollisionRightBumper\x18\x04 \x02(\x08\x12!\n\x19lastComputedCollisionLeft\x18\x05 \x02(\x01\x12\"\n\x1alastComputedCollisionRight\x18\x06 \x02(\x01\"\xf2\x03\n\x07IMUData\x12.\n\x08location\x18\x01 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12.\n\x08velocity\x18\x02 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x32\n\x0c\x61\x63\x63\x65leration\x18\x03 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x39\n\x13\x61\x63\x63\x65leration_sensor\x18\x04 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12.\n\x08rotation\x18\x05 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x39\n\x13rotational_velocity\x18\x06 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12@\n\x1arotational_velocity_sensor\x18\x07 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x31\n\x0borientation\x18\x08 \x02(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x38\n\x12orientation_rotvec\x18\t \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\"\xce\x03\n\x10\x43\x65ntreOfPressure\x12?\n\x19in_and_only_left_foot_cop\x18\x01 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\'\n\x1fin_and_only_left_foot_magnitude\x18\x02 \x02(\x01\x12#\n\x1bin_and_only_left_foot_valid\x18\x03 \x02(\x08\x12@\n\x1ain_and_only_right_foot_cop\x18\x04 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12(\n in_and_only_right_foot_magnitude\x18\x05 \x02(\x01\x12$\n\x1cin_and_only_right_foot_valid\x18\x06 \x02(\x08\x12\x43\n\x1din_kinematic_chain_origin_cop\x18\x07 \x02(\x0b\x32\x1c.naothmessages.DoubleVector3\x12+\n#in_kinematic_chain_origin_magnitude\x18\x08 \x02(\x01\x12\'\n\x1fin_kinematic_chain_origin_valid\x18\t \x02(\x08\"\x8d\x03\n\x12\x43\x61librationDataCMC\x12R\n\x0f\x63\x61librationData\x18\x01 \x03(\x0b\x32\x39.naothmessages.CalibrationDataCMC.CalibrationDataSampleV3\x12\x19\n\x11numberOfResudials\x18\x02 \x01(\r\x1a\x87\x02\n\x17\x43\x61librationDataSampleV3\x12(\n\tchestPose\x18\x01 \x01(\x0b\x32\x15.naothmessages.Pose3D\x12\x33\n\redgelsInImage\x18\x02 \x03(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x36\n\x10\x65\x64gelsInImageTop\x18\x03 \x03(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x31\n\x0borientation\x18\x04 \x01(\x0b\x32\x1c.naothmessages.DoubleVector2\x12\x0f\n\x07headYaw\x18\x05 \x01(\x01\x12\x11\n\theadPitch\x18\x06 \x01(\x01\"\xee\x01\n\x0eWhistlePercept\x12 \n\x18\x66rameWhenWhistleDetected\x18\x01 \x01(\r\x12\x13\n\x0b\x63\x61ptureFile\x18\x02 \x01(\t\x12\x41\n\x12recognizedWhistles\x18\x03 \x03(\x0b\x32%.naothmessages.WhistlePercept.Whistle\x12\x17\n\x0fwhistleDetected\x18\x04 \x01(\x08\x1aI\n\x07Whistle\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x19\n\x11positionInCapture\x18\x02 \x02(\x03\x12\x15\n\rresponseValue\x18\x03 \x02(\x01\"\x83\x01\n\x0b\x44\x65\x62ugModify\x12\x38\n\x08valueMap\x18\x01 \x03(\x0b\x32&.naothmessages.DebugModify.ModifyValue\x1a:\n\x0bModifyValue\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0e\n\x06modify\x18\x02 \x01(\x08\x12\r\n\x05value\x18\x03 \x01(\x01\"9\n\nStepBuffer\x12+\n\x0csupport_foot\x18\x01 \x01(\x0b\x32\x15.naothmessages.Pose3D\"\x8d\x01\n\rbodyAwareness\x12\x10\n\x08isLifted\x18\x01 \x01(\x08\x12\x33\n\rcalculatedCoM\x18\x02 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3\x12\x35\n\x0f\x63urrentCoMError\x18\x03 \x01(\x0b\x32\x1c.naothmessages.DoubleVector3B\x1b\n\x19\x64\x65.naoth.rc.core.messages')
  ,
  dependencies=[CommonTypes__pb2.DESCRIPTOR,Framework__Representations__pb2.DESCRIPTOR,])



_GOALPERCEPT_GOALPOST_POSTTYPE = _descriptor.EnumDescriptor(
  name='PostType',
  full_name='naothmessages.GoalPercept.GoalPost.PostType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='rightPost', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='leftPost', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='unknownPost', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1639,
  serialized_end=1695,
)
_sym_db.RegisterEnumDescriptor(_GOALPERCEPT_GOALPOST_POSTTYPE)

_STEPCONTROLREQUEST_STEPTYPE = _descriptor.EnumDescriptor(
  name='StepType',
  full_name='naothmessages.StepControlRequest.StepType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WALKSTEP', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKSTEP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZEROSTEP', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2485,
  serialized_end=2537,
)
_sym_db.RegisterEnumDescriptor(_STEPCONTROLREQUEST_STEPTYPE)

_STEPCONTROLREQUEST_RESTRICTIONMODE = _descriptor.EnumDescriptor(
  name='RestrictionMode',
  full_name='naothmessages.StepControlRequest.RestrictionMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HARD', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFT', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2539,
  serialized_end=2576,
)
_sym_db.RegisterEnumDescriptor(_STEPCONTROLREQUEST_RESTRICTIONMODE)

_LINEPERCEPT_INTERSECTION_INTERSECTIONTYPE = _descriptor.EnumDescriptor(
  name='IntersectionType',
  full_name='naothmessages.LinePercept.Intersection.IntersectionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='T', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='L', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='C', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='none', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='X', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4418,
  serialized_end=4487,
)
_sym_db.RegisterEnumDescriptor(_LINEPERCEPT_INTERSECTION_INTERSECTIONTYPE)

_BALLCANDIDATES_PATCH_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='naothmessages.BallCandidates.Patch.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Y', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YUV', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YUVC', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7342,
  serialized_end=7374,
)
_sym_db.RegisterEnumDescriptor(_BALLCANDIDATES_PATCH_TYPE)

_REMOTECONTROLCOMMAND_CONTROLMODE = _descriptor.EnumDescriptor(
  name='ControlMode',
  full_name='naothmessages.RemoteControlCommand.ControlMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DIRECT_CONTROL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCK_CONTROL', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7651,
  serialized_end=7702,
)
_sym_db.RegisterEnumDescriptor(_REMOTECONTROLCOMMAND_CONTROLMODE)

_REMOTECONTROLCOMMAND_ACTIONTYPE = _descriptor.EnumDescriptor(
  name='ActionType',
  full_name='naothmessages.RemoteControlCommand.ActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STAND', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WALK', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICK_RIGHT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICK_LEFT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICK_FORWARD_LEFT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICK_FORWARD_RIGHT', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7704,
  serialized_end=7825,
)
_sym_db.RegisterEnumDescriptor(_REMOTECONTROLCOMMAND_ACTIONTYPE)

_REMOTECONTROLCOMMAND_SECONDACTIONTYPE = _descriptor.EnumDescriptor(
  name='SecondActionType',
  full_name='naothmessages.RemoteControlCommand.SecondActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SECOND_NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLINK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAY', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7827,
  serialized_end=7882,
)
_sym_db.RegisterEnumDescriptor(_REMOTECONTROLCOMMAND_SECONDACTIONTYPE)

_GROUNDCONTACTMODEL_FOOT = _descriptor.EnumDescriptor(
  name='Foot',
  full_name='naothmessages.GroundContactModel.Foot',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8023,
  serialized_end=8060,
)
_sym_db.RegisterEnumDescriptor(_GROUNDCONTACTMODEL_FOOT)


_CAMERAMATRIX = _descriptor.Descriptor(
  name='CameraMatrix',
  full_name='naothmessages.CameraMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='naothmessages.CameraMatrix.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cameraID', full_name='naothmessages.CameraMatrix.cameraID', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='valid', full_name='naothmessages.CameraMatrix.valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='naothmessages.CameraMatrix.timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=229,
)


_BALLPERCEPT = _descriptor.Descriptor(
  name='BallPercept',
  full_name='naothmessages.BallPercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ballWasSeen', full_name='naothmessages.BallPercept.ballWasSeen', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='centerInImage', full_name='naothmessages.BallPercept.centerInImage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiusInImage', full_name='naothmessages.BallPercept.radiusInImage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ballColor', full_name='naothmessages.BallPercept.ballColor', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bearingBasedOffsetOnField', full_name='naothmessages.BallPercept.bearingBasedOffsetOnField', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frameInfoWhenBallWasSeen', full_name='naothmessages.BallPercept.frameInfoWhenBallWasSeen', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=508,
)


_MULTIBALLPERCEPT_BALLPERCEPT = _descriptor.Descriptor(
  name='BallPercept',
  full_name='naothmessages.MultiBallPercept.BallPercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='centerInImage', full_name='naothmessages.MultiBallPercept.BallPercept.centerInImage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiusInImage', full_name='naothmessages.MultiBallPercept.BallPercept.radiusInImage', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positionOnField', full_name='naothmessages.MultiBallPercept.BallPercept.positionOnField', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cameraId', full_name='naothmessages.MultiBallPercept.BallPercept.cameraId', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=842,
)

_MULTIBALLPERCEPT = _descriptor.Descriptor(
  name='MultiBallPercept',
  full_name='naothmessages.MultiBallPercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frameInfoWhenBallWasSeen', full_name='naothmessages.MultiBallPercept.frameInfoWhenBallWasSeen', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percepts', full_name='naothmessages.MultiBallPercept.percepts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MULTIBALLPERCEPT_BALLPERCEPT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=842,
)


_BALLMODEL = _descriptor.Descriptor(
  name='BallModel',
  full_name='naothmessages.BallModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='naothmessages.BallModel.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='knows', full_name='naothmessages.BallModel.knows', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='naothmessages.BallModel.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speed', full_name='naothmessages.BallModel.speed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positionPreview', full_name='naothmessages.BallModel.positionPreview', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positionPreviewInLFoot', full_name='naothmessages.BallModel.positionPreviewInLFoot', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positionPreviewInRFoot', full_name='naothmessages.BallModel.positionPreviewInRFoot', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='futurePosition', full_name='naothmessages.BallModel.futurePosition', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=1216,
)


_GOALPERCEPT_GOALPOST = _descriptor.Descriptor(
  name='GoalPost',
  full_name='naothmessages.GoalPercept.GoalPost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='basePoint', full_name='naothmessages.GoalPercept.GoalPost.basePoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='naothmessages.GoalPercept.GoalPost.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='naothmessages.GoalPercept.GoalPost.color', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='naothmessages.GoalPercept.GoalPost.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positionReliable', full_name='naothmessages.GoalPercept.GoalPost.positionReliable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seenHeight', full_name='naothmessages.GoalPercept.GoalPost.seenHeight', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GOALPERCEPT_GOALPOST_POSTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1390,
  serialized_end=1695,
)

_GOALPERCEPT = _descriptor.Descriptor(
  name='GoalPercept',
  full_name='naothmessages.GoalPercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angleToSeenGoal', full_name='naothmessages.GoalPercept.angleToSeenGoal', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='goalCentroid', full_name='naothmessages.GoalPercept.goalCentroid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numberOfSeenPosts', full_name='naothmessages.GoalPercept.numberOfSeenPosts', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='post', full_name='naothmessages.GoalPercept.post', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GOALPERCEPT_GOALPOST, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1695,
)


_HEADMOTIONREQUEST = _descriptor.Descriptor(
  name='HeadMotionRequest',
  full_name='naothmessages.HeadMotionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.HeadMotionRequest.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cameraID', full_name='naothmessages.HeadMotionRequest.cameraID', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetJointPosition', full_name='naothmessages.HeadMotionRequest.targetJointPosition', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetPointInImage', full_name='naothmessages.HeadMotionRequest.targetPointInImage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetPointInTheWorld', full_name='naothmessages.HeadMotionRequest.targetPointInTheWorld', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='searchCenter', full_name='naothmessages.HeadMotionRequest.searchCenter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='searchSize', full_name='naothmessages.HeadMotionRequest.searchSize', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='searchDirection', full_name='naothmessages.HeadMotionRequest.searchDirection', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='targetPointOnTheGround', full_name='naothmessages.HeadMotionRequest.targetPointOnTheGround', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coordinate', full_name='naothmessages.HeadMotionRequest.coordinate', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='naothmessages.HeadMotionRequest.velocity', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1698,
  serialized_end=2152,
)


_STEPCONTROLREQUEST = _descriptor.Descriptor(
  name='StepControlRequest',
  full_name='naothmessages.StepControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepID', full_name='naothmessages.StepControlRequest.stepID', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='moveLeftFoot', full_name='naothmessages.StepControlRequest.moveLeftFoot', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target', full_name='naothmessages.StepControlRequest.target', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='naothmessages.StepControlRequest.time', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speedDirection', full_name='naothmessages.StepControlRequest.speedDirection', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scale', full_name='naothmessages.StepControlRequest.scale', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steptype', full_name='naothmessages.StepControlRequest.steptype', index=6,
      number=7, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='restriction', full_name='naothmessages.StepControlRequest.restriction', index=7,
      number=8, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='isProtected', full_name='naothmessages.StepControlRequest.isProtected', index=8,
      number=9, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepRequestID', full_name='naothmessages.StepControlRequest.stepRequestID', index=9,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STEPCONTROLREQUEST_STEPTYPE,
    _STEPCONTROLREQUEST_RESTRICTIONMODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2576,
)


_WALKREQUEST = _descriptor.Descriptor(
  name='WalkRequest',
  full_name='naothmessages.WalkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinate', full_name='naothmessages.WalkRequest.coordinate', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='character', full_name='naothmessages.WalkRequest.character', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target', full_name='naothmessages.WalkRequest.target', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepControl', full_name='naothmessages.WalkRequest.stepControl', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='naothmessages.WalkRequest.offset', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2579,
  serialized_end=2765,
)


_KICKREQUEST = _descriptor.Descriptor(
  name='KickRequest',
  full_name='naothmessages.KickRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kickPoint', full_name='naothmessages.KickRequest.kickPoint', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kickDirection', full_name='naothmessages.KickRequest.kickDirection', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kickFoot', full_name='naothmessages.KickRequest.kickFoot', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='finishKick', full_name='naothmessages.KickRequest.finishKick', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2767,
  serialized_end=2890,
)


_GRASPREQUEST = _descriptor.Descriptor(
  name='GraspRequest',
  full_name='naothmessages.GraspRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='graspingPoint', full_name='naothmessages.GraspRequest.graspingPoint', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graspingState', full_name='naothmessages.GraspRequest.graspingState', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graspDistState', full_name='naothmessages.GraspRequest.graspDistState', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graspStiffState', full_name='naothmessages.GraspRequest.graspStiffState', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2893,
  serialized_end=3032,
)


_ARMMOTIONREQUEST = _descriptor.Descriptor(
  name='ArmMotionRequest',
  full_name='naothmessages.ArmMotionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.ArmMotionRequest.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lShoulderPosition', full_name='naothmessages.ArmMotionRequest.lShoulderPosition', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lShoulderStiffness', full_name='naothmessages.ArmMotionRequest.lShoulderStiffness', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lElbowPosition', full_name='naothmessages.ArmMotionRequest.lElbowPosition', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lElbowStiffness', full_name='naothmessages.ArmMotionRequest.lElbowStiffness', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rShoulderPosition', full_name='naothmessages.ArmMotionRequest.rShoulderPosition', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rShoulderStiffness', full_name='naothmessages.ArmMotionRequest.rShoulderStiffness', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rElbowPosition', full_name='naothmessages.ArmMotionRequest.rElbowPosition', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rElbowStiffness', full_name='naothmessages.ArmMotionRequest.rElbowStiffness', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3035,
  serialized_end=3513,
)


_MOTIONREQUEST = _descriptor.Descriptor(
  name='MotionRequest',
  full_name='naothmessages.MotionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.MotionRequest.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='naothmessages.MotionRequest.time', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='forced', full_name='naothmessages.MotionRequest.forced', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='walkRequest', full_name='naothmessages.MotionRequest.walkRequest', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='starndardStand', full_name='naothmessages.MotionRequest.starndardStand', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kickRequest', full_name='naothmessages.MotionRequest.kickRequest', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='standHeight', full_name='naothmessages.MotionRequest.standHeight', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibrateFootTouchDetector', full_name='naothmessages.MotionRequest.calibrateFootTouchDetector', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cognitionFrameNumber', full_name='naothmessages.MotionRequest.cognitionFrameNumber', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graspRequest', full_name='naothmessages.MotionRequest.graspRequest', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='armMotionRequest', full_name='naothmessages.MotionRequest.armMotionRequest', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='disable_relaxed_stand', full_name='naothmessages.MotionRequest.disable_relaxed_stand', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3516,
  serialized_end=3923,
)


_LINEPERCEPT_INTERSECTION = _descriptor.Descriptor(
  name='Intersection',
  full_name='naothmessages.LinePercept.Intersection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='posInImage', full_name='naothmessages.LinePercept.Intersection.posInImage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='posOnField', full_name='naothmessages.LinePercept.Intersection.posOnField', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='naothmessages.LinePercept.Intersection.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='segmentOneIndex', full_name='naothmessages.LinePercept.Intersection.segmentOneIndex', index=3,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='segmentTwoIndex', full_name='naothmessages.LinePercept.Intersection.segmentTwoIndex', index=4,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='segmentOneDistance', full_name='naothmessages.LinePercept.Intersection.segmentOneDistance', index=5,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='segmentTwoDistance', full_name='naothmessages.LinePercept.Intersection.segmentTwoDistance', index=6,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LINEPERCEPT_INTERSECTION_INTERSECTIONTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4124,
  serialized_end=4487,
)

_LINEPERCEPT_FIELDLINESEGMENT = _descriptor.Descriptor(
  name='FieldLineSegment',
  full_name='naothmessages.LinePercept.FieldLineSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lineInImage', full_name='naothmessages.LinePercept.FieldLineSegment.lineInImage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lineOnField', full_name='naothmessages.LinePercept.FieldLineSegment.lineOnField', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='beginExtendCount', full_name='naothmessages.LinePercept.FieldLineSegment.beginExtendCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endExtendCount', full_name='naothmessages.LinePercept.FieldLineSegment.endExtendCount', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='thickness', full_name='naothmessages.LinePercept.FieldLineSegment.thickness', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slope', full_name='naothmessages.LinePercept.FieldLineSegment.slope', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angle', full_name='naothmessages.LinePercept.FieldLineSegment.angle', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='valid', full_name='naothmessages.LinePercept.FieldLineSegment.valid', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4490,
  serialized_end=4720,
)

_LINEPERCEPT = _descriptor.Descriptor(
  name='LinePercept',
  full_name='naothmessages.LinePercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lines', full_name='naothmessages.LinePercept.lines', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='intersections', full_name='naothmessages.LinePercept.intersections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='middleCircleCenter', full_name='naothmessages.LinePercept.middleCircleCenter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_LINEPERCEPT_INTERSECTION, _LINEPERCEPT_FIELDLINESEGMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3926,
  serialized_end=4720,
)


_SHORTLINEPERCEPT = _descriptor.Descriptor(
  name='ShortLinePercept',
  full_name='naothmessages.ShortLinePercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldLineSegments', full_name='naothmessages.ShortLinePercept.fieldLineSegments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4722,
  serialized_end=4795,
)


_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='naothmessages.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='naothmessages.Polygon.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4797,
  serialized_end=4849,
)


_FIELDPERCEPT = _descriptor.Descriptor(
  name='FieldPercept',
  full_name='naothmessages.FieldPercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldPoly', full_name='naothmessages.FieldPercept.fieldPoly', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4851,
  serialized_end=4908,
)


_RANSACLINEPERCEPT = _descriptor.Descriptor(
  name='RansacLinePercept',
  full_name='naothmessages.RansacLinePercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldLineSegments', full_name='naothmessages.RansacLinePercept.fieldLineSegments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4910,
  serialized_end=4984,
)


_RANSACCIRCLEPERCEPT2018 = _descriptor.Descriptor(
  name='RansacCirclePercept2018',
  full_name='naothmessages.RansacCirclePercept2018',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wasSeen', full_name='naothmessages.RansacCirclePercept2018.wasSeen', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='middleCircleCenter', full_name='naothmessages.RansacCirclePercept2018.middleCircleCenter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4986,
  serialized_end=5086,
)


_SCANLINEENDPOINT = _descriptor.Descriptor(
  name='ScanLineEndPoint',
  full_name='naothmessages.ScanLineEndPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='posInImage', full_name='naothmessages.ScanLineEndPoint.posInImage', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='posOnField', full_name='naothmessages.ScanLineEndPoint.posOnField', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='naothmessages.ScanLineEndPoint.color', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ScanLineID', full_name='naothmessages.ScanLineEndPoint.ScanLineID', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5089,
  serialized_end=5261,
)


_DOUBLEEDGEL = _descriptor.Descriptor(
  name='DoubleEdgel',
  full_name='naothmessages.DoubleEdgel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='naothmessages.DoubleEdgel.point', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='direction', full_name='naothmessages.DoubleEdgel.direction', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5263,
  serialized_end=5370,
)


_EDGEL = _descriptor.Descriptor(
  name='Edgel',
  full_name='naothmessages.Edgel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='naothmessages.Edgel.point', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='direction', full_name='naothmessages.Edgel.direction', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5372,
  serialized_end=5470,
)


_EDGELPAIR = _descriptor.Descriptor(
  name='EdgelPair',
  full_name='naothmessages.EdgelPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin', full_name='naothmessages.EdgelPair.begin', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='naothmessages.EdgelPair.end', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='naothmessages.EdgelPair.id', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='adaptive', full_name='naothmessages.EdgelPair.adaptive', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5472,
  serialized_end=5541,
)


_SCANLINEEDGELPERCEPT = _descriptor.Descriptor(
  name='ScanLineEdgelPercept',
  full_name='naothmessages.ScanLineEdgelPercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edgels', full_name='naothmessages.ScanLineEdgelPercept.edgels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pairs', full_name='naothmessages.ScanLineEdgelPercept.pairs', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endPoints', full_name='naothmessages.ScanLineEdgelPercept.endPoints', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5544,
  serialized_end=5697,
)


_LINEGRAPHPERCEPT = _descriptor.Descriptor(
  name='LineGraphPercept',
  full_name='naothmessages.LineGraphPercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edgelsOnField', full_name='naothmessages.LineGraphPercept.edgelsOnField', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edgelsInImageTop', full_name='naothmessages.LineGraphPercept.edgelsInImageTop', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edgelsInImage', full_name='naothmessages.LineGraphPercept.edgelsInImage', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5700,
  serialized_end=5868,
)


_STEPCONTROLSTATUS = _descriptor.Descriptor(
  name='StepControlStatus',
  full_name='naothmessages.StepControlStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepID', full_name='naothmessages.StepControlStatus.stepID', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='moveableFoot', full_name='naothmessages.StepControlStatus.moveableFoot', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepRequestID', full_name='naothmessages.StepControlStatus.stepRequestID', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5870,
  serialized_end=5950,
)


_MOTIONSTATUS = _descriptor.Descriptor(
  name='MotionStatus',
  full_name='naothmessages.MotionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='naothmessages.MotionStatus.time', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastMotion', full_name='naothmessages.MotionStatus.lastMotion', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currentMotion', full_name='naothmessages.MotionStatus.currentMotion', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='headMotion', full_name='naothmessages.MotionStatus.headMotion', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currentMotionState', full_name='naothmessages.MotionStatus.currentMotionState', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='plannedMotionLeftFoot', full_name='naothmessages.MotionStatus.plannedMotionLeftFoot', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='plannedMotionRightFoot', full_name='naothmessages.MotionStatus.plannedMotionRightFoot', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='plannedMotionHip', full_name='naothmessages.MotionStatus.plannedMotionHip', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepControlStatus', full_name='naothmessages.MotionStatus.stepControlStatus', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_reached', full_name='naothmessages.MotionStatus.target_reached', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='head_target_reached', full_name='naothmessages.MotionStatus.head_target_reached', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='head_got_stuck', full_name='naothmessages.MotionStatus.head_got_stuck', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='walk_emergency_stop', full_name='naothmessages.MotionStatus.walk_emergency_stop', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='head_at_rest', full_name='naothmessages.MotionStatus.head_at_rest', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5953,
  serialized_end=6419,
)


_ODOMETRYDATA = _descriptor.Descriptor(
  name='OdometryData',
  full_name='naothmessages.OdometryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='naothmessages.OdometryData.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6421,
  serialized_end=6472,
)


_BODYSTATE = _descriptor.Descriptor(
  name='BodyState',
  full_name='naothmessages.BodyState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isLiftedUp', full_name='naothmessages.BodyState.isLiftedUp', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6474,
  serialized_end=6505,
)


_BODYSTATUS = _descriptor.Descriptor(
  name='BodyStatus',
  full_name='naothmessages.BodyStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentSum', full_name='naothmessages.BodyStatus.currentSum', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='naothmessages.BodyStatus.timestamp', index=1,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6507,
  serialized_end=6558,
)


_CALIBRATIONDATA = _descriptor.Descriptor(
  name='CalibrationData',
  full_name='naothmessages.CalibrationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inertialSensorOffset', full_name='naothmessages.CalibrationData.inertialSensorOffset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gyroSensorOffset', full_name='naothmessages.CalibrationData.gyroSensorOffset', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accSensorOffset', full_name='naothmessages.CalibrationData.accSensorOffset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibrated', full_name='naothmessages.CalibrationData.calibrated', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6561,
  serialized_end=6769,
)


_INERTIALMODEL = _descriptor.Descriptor(
  name='InertialModel',
  full_name='naothmessages.InertialModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orientation', full_name='naothmessages.InertialModel.orientation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6771,
  serialized_end=6837,
)


_CAMERAMATRIXCALIBRATION = _descriptor.Descriptor(
  name='CameraMatrixCalibration',
  full_name='naothmessages.CameraMatrixCalibration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correctionOffset', full_name='naothmessages.CameraMatrixCalibration.correctionOffset', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='correctionOffsetBody', full_name='naothmessages.CameraMatrixCalibration.correctionOffsetBody', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='correctionOffsetHead', full_name='naothmessages.CameraMatrixCalibration.correctionOffsetHead', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='correctionOffsetCam', full_name='naothmessages.CameraMatrixCalibration.correctionOffsetCam', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6840,
  serialized_end=7104,
)


_BALLCANDIDATES_PATCH = _descriptor.Descriptor(
  name='Patch',
  full_name='naothmessages.BallCandidates.Patch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='naothmessages.BallCandidates.Patch.min', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max', full_name='naothmessages.BallCandidates.Patch.max', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='naothmessages.BallCandidates.Patch.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='naothmessages.BallCandidates.Patch.data', index=3,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BALLCANDIDATES_PATCH_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7180,
  serialized_end=7374,
)

_BALLCANDIDATES = _descriptor.Descriptor(
  name='BallCandidates',
  full_name='naothmessages.BallCandidates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='patches', full_name='naothmessages.BallCandidates.patches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_BALLCANDIDATES_PATCH, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7107,
  serialized_end=7374,
)


_REMOTECONTROLCOMMAND = _descriptor.Descriptor(
  name='RemoteControlCommand',
  full_name='naothmessages.RemoteControlCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='controlMode', full_name='naothmessages.RemoteControlCommand.controlMode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='naothmessages.RemoteControlCommand.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second_action', full_name='naothmessages.RemoteControlCommand.second_action', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target', full_name='naothmessages.RemoteControlCommand.target', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REMOTECONTROLCOMMAND_CONTROLMODE,
    _REMOTECONTROLCOMMAND_ACTIONTYPE,
    _REMOTECONTROLCOMMAND_SECONDACTIONTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7377,
  serialized_end=7882,
)


_GROUNDCONTACTMODEL = _descriptor.Descriptor(
  name='GroundContactModel',
  full_name='naothmessages.GroundContactModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='leftGroundContact', full_name='naothmessages.GroundContactModel.leftGroundContact', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rightGroundContact', full_name='naothmessages.GroundContactModel.rightGroundContact', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='supportFoot', full_name='naothmessages.GroundContactModel.supportFoot', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUNDCONTACTMODEL_FOOT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7885,
  serialized_end=8060,
)


_COLLISIONPERCEPT = _descriptor.Descriptor(
  name='CollisionPercept',
  full_name='naothmessages.CollisionPercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeCollisionArmLeft', full_name='naothmessages.CollisionPercept.timeCollisionArmLeft', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeCollisionArmRight', full_name='naothmessages.CollisionPercept.timeCollisionArmRight', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='isCollisionLeftBumper', full_name='naothmessages.CollisionPercept.isCollisionLeftBumper', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='isCollisionRightBumper', full_name='naothmessages.CollisionPercept.isCollisionRightBumper', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastComputedCollisionLeft', full_name='naothmessages.CollisionPercept.lastComputedCollisionLeft', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastComputedCollisionRight', full_name='naothmessages.CollisionPercept.lastComputedCollisionRight', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8063,
  serialized_end=8276,
)


_IMUDATA = _descriptor.Descriptor(
  name='IMUData',
  full_name='naothmessages.IMUData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='naothmessages.IMUData.location', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='naothmessages.IMUData.velocity', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='naothmessages.IMUData.acceleration', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='acceleration_sensor', full_name='naothmessages.IMUData.acceleration_sensor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='naothmessages.IMUData.rotation', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotational_velocity', full_name='naothmessages.IMUData.rotational_velocity', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotational_velocity_sensor', full_name='naothmessages.IMUData.rotational_velocity_sensor', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='naothmessages.IMUData.orientation', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation_rotvec', full_name='naothmessages.IMUData.orientation_rotvec', index=8,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8279,
  serialized_end=8777,
)


_CENTREOFPRESSURE = _descriptor.Descriptor(
  name='CentreOfPressure',
  full_name='naothmessages.CentreOfPressure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='in_and_only_left_foot_cop', full_name='naothmessages.CentreOfPressure.in_and_only_left_foot_cop', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_and_only_left_foot_magnitude', full_name='naothmessages.CentreOfPressure.in_and_only_left_foot_magnitude', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_and_only_left_foot_valid', full_name='naothmessages.CentreOfPressure.in_and_only_left_foot_valid', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_and_only_right_foot_cop', full_name='naothmessages.CentreOfPressure.in_and_only_right_foot_cop', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_and_only_right_foot_magnitude', full_name='naothmessages.CentreOfPressure.in_and_only_right_foot_magnitude', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_and_only_right_foot_valid', full_name='naothmessages.CentreOfPressure.in_and_only_right_foot_valid', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_kinematic_chain_origin_cop', full_name='naothmessages.CentreOfPressure.in_kinematic_chain_origin_cop', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_kinematic_chain_origin_magnitude', full_name='naothmessages.CentreOfPressure.in_kinematic_chain_origin_magnitude', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_kinematic_chain_origin_valid', full_name='naothmessages.CentreOfPressure.in_kinematic_chain_origin_valid', index=8,
      number=9, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8780,
  serialized_end=9242,
)


_CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3 = _descriptor.Descriptor(
  name='CalibrationDataSampleV3',
  full_name='naothmessages.CalibrationDataCMC.CalibrationDataSampleV3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chestPose', full_name='naothmessages.CalibrationDataCMC.CalibrationDataSampleV3.chestPose', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edgelsInImage', full_name='naothmessages.CalibrationDataCMC.CalibrationDataSampleV3.edgelsInImage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edgelsInImageTop', full_name='naothmessages.CalibrationDataCMC.CalibrationDataSampleV3.edgelsInImageTop', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='naothmessages.CalibrationDataCMC.CalibrationDataSampleV3.orientation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='headYaw', full_name='naothmessages.CalibrationDataCMC.CalibrationDataSampleV3.headYaw', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='headPitch', full_name='naothmessages.CalibrationDataCMC.CalibrationDataSampleV3.headPitch', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9379,
  serialized_end=9642,
)

_CALIBRATIONDATACMC = _descriptor.Descriptor(
  name='CalibrationDataCMC',
  full_name='naothmessages.CalibrationDataCMC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calibrationData', full_name='naothmessages.CalibrationDataCMC.calibrationData', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numberOfResudials', full_name='naothmessages.CalibrationDataCMC.numberOfResudials', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9245,
  serialized_end=9642,
)


_WHISTLEPERCEPT_WHISTLE = _descriptor.Descriptor(
  name='Whistle',
  full_name='naothmessages.WhistlePercept.Whistle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.WhistlePercept.Whistle.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positionInCapture', full_name='naothmessages.WhistlePercept.Whistle.positionInCapture', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responseValue', full_name='naothmessages.WhistlePercept.Whistle.responseValue', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9810,
  serialized_end=9883,
)

_WHISTLEPERCEPT = _descriptor.Descriptor(
  name='WhistlePercept',
  full_name='naothmessages.WhistlePercept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frameWhenWhistleDetected', full_name='naothmessages.WhistlePercept.frameWhenWhistleDetected', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='captureFile', full_name='naothmessages.WhistlePercept.captureFile', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recognizedWhistles', full_name='naothmessages.WhistlePercept.recognizedWhistles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whistleDetected', full_name='naothmessages.WhistlePercept.whistleDetected', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_WHISTLEPERCEPT_WHISTLE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9645,
  serialized_end=9883,
)


_DEBUGMODIFY_MODIFYVALUE = _descriptor.Descriptor(
  name='ModifyValue',
  full_name='naothmessages.DebugModify.ModifyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='naothmessages.DebugModify.ModifyValue.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modify', full_name='naothmessages.DebugModify.ModifyValue.modify', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='naothmessages.DebugModify.ModifyValue.value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9959,
  serialized_end=10017,
)

_DEBUGMODIFY = _descriptor.Descriptor(
  name='DebugModify',
  full_name='naothmessages.DebugModify',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valueMap', full_name='naothmessages.DebugModify.valueMap', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_DEBUGMODIFY_MODIFYVALUE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9886,
  serialized_end=10017,
)


_STEPBUFFER = _descriptor.Descriptor(
  name='StepBuffer',
  full_name='naothmessages.StepBuffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='support_foot', full_name='naothmessages.StepBuffer.support_foot', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10019,
  serialized_end=10076,
)


_BODYAWARENESS = _descriptor.Descriptor(
  name='bodyAwareness',
  full_name='naothmessages.bodyAwareness',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isLifted', full_name='naothmessages.bodyAwareness.isLifted', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calculatedCoM', full_name='naothmessages.bodyAwareness.calculatedCoM', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currentCoMError', full_name='naothmessages.bodyAwareness.currentCoMError', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10079,
  serialized_end=10220,
)

_CAMERAMATRIX.fields_by_name['pose'].message_type = CommonTypes__pb2._POSE3D
_CAMERAMATRIX.fields_by_name['cameraID'].enum_type = CommonTypes__pb2._CAMERAID
_BALLPERCEPT.fields_by_name['centerInImage'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_BALLPERCEPT.fields_by_name['ballColor'].enum_type = CommonTypes__pb2._COLOR
_BALLPERCEPT.fields_by_name['bearingBasedOffsetOnField'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_BALLPERCEPT.fields_by_name['frameInfoWhenBallWasSeen'].message_type = Framework__Representations__pb2._FRAMEINFO
_MULTIBALLPERCEPT_BALLPERCEPT.fields_by_name['centerInImage'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_MULTIBALLPERCEPT_BALLPERCEPT.fields_by_name['positionOnField'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_MULTIBALLPERCEPT_BALLPERCEPT.fields_by_name['cameraId'].enum_type = CommonTypes__pb2._CAMERAID
_MULTIBALLPERCEPT_BALLPERCEPT.containing_type = _MULTIBALLPERCEPT
_MULTIBALLPERCEPT.fields_by_name['frameInfoWhenBallWasSeen'].message_type = Framework__Representations__pb2._FRAMEINFO
_MULTIBALLPERCEPT.fields_by_name['percepts'].message_type = _MULTIBALLPERCEPT_BALLPERCEPT
_BALLMODEL.fields_by_name['position'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_BALLMODEL.fields_by_name['speed'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_BALLMODEL.fields_by_name['positionPreview'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_BALLMODEL.fields_by_name['positionPreviewInLFoot'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_BALLMODEL.fields_by_name['positionPreviewInRFoot'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_BALLMODEL.fields_by_name['futurePosition'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_GOALPERCEPT_GOALPOST.fields_by_name['basePoint'].message_type = CommonTypes__pb2._INTVECTOR2
_GOALPERCEPT_GOALPOST.fields_by_name['position'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_GOALPERCEPT_GOALPOST.fields_by_name['color'].enum_type = CommonTypes__pb2._COLOR
_GOALPERCEPT_GOALPOST.fields_by_name['type'].enum_type = _GOALPERCEPT_GOALPOST_POSTTYPE
_GOALPERCEPT_GOALPOST.containing_type = _GOALPERCEPT
_GOALPERCEPT_GOALPOST_POSTTYPE.containing_type = _GOALPERCEPT_GOALPOST
_GOALPERCEPT.fields_by_name['goalCentroid'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_GOALPERCEPT.fields_by_name['post'].message_type = _GOALPERCEPT_GOALPOST
_HEADMOTIONREQUEST.fields_by_name['targetJointPosition'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_HEADMOTIONREQUEST.fields_by_name['targetPointInImage'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_HEADMOTIONREQUEST.fields_by_name['targetPointInTheWorld'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_HEADMOTIONREQUEST.fields_by_name['searchCenter'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_HEADMOTIONREQUEST.fields_by_name['searchSize'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_HEADMOTIONREQUEST.fields_by_name['targetPointOnTheGround'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_STEPCONTROLREQUEST.fields_by_name['target'].message_type = CommonTypes__pb2._POSE2D
_STEPCONTROLREQUEST.fields_by_name['steptype'].enum_type = _STEPCONTROLREQUEST_STEPTYPE
_STEPCONTROLREQUEST.fields_by_name['restriction'].enum_type = _STEPCONTROLREQUEST_RESTRICTIONMODE
_STEPCONTROLREQUEST_STEPTYPE.containing_type = _STEPCONTROLREQUEST
_STEPCONTROLREQUEST_RESTRICTIONMODE.containing_type = _STEPCONTROLREQUEST
_WALKREQUEST.fields_by_name['target'].message_type = CommonTypes__pb2._POSE2D
_WALKREQUEST.fields_by_name['stepControl'].message_type = _STEPCONTROLREQUEST
_WALKREQUEST.fields_by_name['offset'].message_type = CommonTypes__pb2._POSE2D
_KICKREQUEST.fields_by_name['kickPoint'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_GRASPREQUEST.fields_by_name['graspingPoint'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_ARMMOTIONREQUEST.fields_by_name['lShoulderPosition'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_ARMMOTIONREQUEST.fields_by_name['lShoulderStiffness'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_ARMMOTIONREQUEST.fields_by_name['lElbowPosition'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_ARMMOTIONREQUEST.fields_by_name['lElbowStiffness'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_ARMMOTIONREQUEST.fields_by_name['rShoulderPosition'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_ARMMOTIONREQUEST.fields_by_name['rShoulderStiffness'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_ARMMOTIONREQUEST.fields_by_name['rElbowPosition'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_ARMMOTIONREQUEST.fields_by_name['rElbowStiffness'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_MOTIONREQUEST.fields_by_name['walkRequest'].message_type = _WALKREQUEST
_MOTIONREQUEST.fields_by_name['kickRequest'].message_type = _KICKREQUEST
_MOTIONREQUEST.fields_by_name['graspRequest'].message_type = _GRASPREQUEST
_MOTIONREQUEST.fields_by_name['armMotionRequest'].message_type = _ARMMOTIONREQUEST
_LINEPERCEPT_INTERSECTION.fields_by_name['posInImage'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_LINEPERCEPT_INTERSECTION.fields_by_name['posOnField'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_LINEPERCEPT_INTERSECTION.fields_by_name['type'].enum_type = _LINEPERCEPT_INTERSECTION_INTERSECTIONTYPE
_LINEPERCEPT_INTERSECTION.containing_type = _LINEPERCEPT
_LINEPERCEPT_INTERSECTION_INTERSECTIONTYPE.containing_type = _LINEPERCEPT_INTERSECTION
_LINEPERCEPT_FIELDLINESEGMENT.fields_by_name['lineInImage'].message_type = CommonTypes__pb2._LINESEGMENT
_LINEPERCEPT_FIELDLINESEGMENT.fields_by_name['lineOnField'].message_type = CommonTypes__pb2._LINESEGMENT
_LINEPERCEPT_FIELDLINESEGMENT.containing_type = _LINEPERCEPT
_LINEPERCEPT.fields_by_name['lines'].message_type = _LINEPERCEPT_FIELDLINESEGMENT
_LINEPERCEPT.fields_by_name['intersections'].message_type = _LINEPERCEPT_INTERSECTION
_LINEPERCEPT.fields_by_name['middleCircleCenter'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_SHORTLINEPERCEPT.fields_by_name['fieldLineSegments'].message_type = CommonTypes__pb2._LINESEGMENT
_POLYGON.fields_by_name['points'].message_type = CommonTypes__pb2._INTVECTOR2
_FIELDPERCEPT.fields_by_name['fieldPoly'].message_type = _POLYGON
_RANSACLINEPERCEPT.fields_by_name['fieldLineSegments'].message_type = CommonTypes__pb2._LINESEGMENT
_RANSACCIRCLEPERCEPT2018.fields_by_name['middleCircleCenter'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_SCANLINEENDPOINT.fields_by_name['posInImage'].message_type = CommonTypes__pb2._INTVECTOR2
_SCANLINEENDPOINT.fields_by_name['posOnField'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_SCANLINEENDPOINT.fields_by_name['color'].enum_type = CommonTypes__pb2._COLOR
_DOUBLEEDGEL.fields_by_name['point'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_DOUBLEEDGEL.fields_by_name['direction'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_EDGEL.fields_by_name['point'].message_type = CommonTypes__pb2._INTVECTOR2
_EDGEL.fields_by_name['direction'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_SCANLINEEDGELPERCEPT.fields_by_name['edgels'].message_type = _EDGEL
_SCANLINEEDGELPERCEPT.fields_by_name['pairs'].message_type = _EDGELPAIR
_SCANLINEEDGELPERCEPT.fields_by_name['endPoints'].message_type = _SCANLINEENDPOINT
_LINEGRAPHPERCEPT.fields_by_name['edgelsOnField'].message_type = _EDGEL
_LINEGRAPHPERCEPT.fields_by_name['edgelsInImageTop'].message_type = _DOUBLEEDGEL
_LINEGRAPHPERCEPT.fields_by_name['edgelsInImage'].message_type = _DOUBLEEDGEL
_MOTIONSTATUS.fields_by_name['plannedMotionLeftFoot'].message_type = CommonTypes__pb2._POSE2D
_MOTIONSTATUS.fields_by_name['plannedMotionRightFoot'].message_type = CommonTypes__pb2._POSE2D
_MOTIONSTATUS.fields_by_name['plannedMotionHip'].message_type = CommonTypes__pb2._POSE2D
_MOTIONSTATUS.fields_by_name['stepControlStatus'].message_type = _STEPCONTROLSTATUS
_ODOMETRYDATA.fields_by_name['pose'].message_type = CommonTypes__pb2._POSE2D
_CALIBRATIONDATA.fields_by_name['inertialSensorOffset'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_CALIBRATIONDATA.fields_by_name['gyroSensorOffset'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_CALIBRATIONDATA.fields_by_name['accSensorOffset'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_INERTIALMODEL.fields_by_name['orientation'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_CAMERAMATRIXCALIBRATION.fields_by_name['correctionOffset'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_CAMERAMATRIXCALIBRATION.fields_by_name['correctionOffsetBody'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_CAMERAMATRIXCALIBRATION.fields_by_name['correctionOffsetHead'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_CAMERAMATRIXCALIBRATION.fields_by_name['correctionOffsetCam'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_BALLCANDIDATES_PATCH.fields_by_name['min'].message_type = CommonTypes__pb2._INTVECTOR2
_BALLCANDIDATES_PATCH.fields_by_name['max'].message_type = CommonTypes__pb2._INTVECTOR2
_BALLCANDIDATES_PATCH.fields_by_name['type'].enum_type = _BALLCANDIDATES_PATCH_TYPE
_BALLCANDIDATES_PATCH.containing_type = _BALLCANDIDATES
_BALLCANDIDATES_PATCH_TYPE.containing_type = _BALLCANDIDATES_PATCH
_BALLCANDIDATES.fields_by_name['patches'].message_type = _BALLCANDIDATES_PATCH
_REMOTECONTROLCOMMAND.fields_by_name['controlMode'].enum_type = _REMOTECONTROLCOMMAND_CONTROLMODE
_REMOTECONTROLCOMMAND.fields_by_name['action'].enum_type = _REMOTECONTROLCOMMAND_ACTIONTYPE
_REMOTECONTROLCOMMAND.fields_by_name['second_action'].enum_type = _REMOTECONTROLCOMMAND_SECONDACTIONTYPE
_REMOTECONTROLCOMMAND.fields_by_name['target'].message_type = CommonTypes__pb2._POSE2D
_REMOTECONTROLCOMMAND_CONTROLMODE.containing_type = _REMOTECONTROLCOMMAND
_REMOTECONTROLCOMMAND_ACTIONTYPE.containing_type = _REMOTECONTROLCOMMAND
_REMOTECONTROLCOMMAND_SECONDACTIONTYPE.containing_type = _REMOTECONTROLCOMMAND
_GROUNDCONTACTMODEL.fields_by_name['supportFoot'].enum_type = _GROUNDCONTACTMODEL_FOOT
_GROUNDCONTACTMODEL_FOOT.containing_type = _GROUNDCONTACTMODEL
_IMUDATA.fields_by_name['location'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_IMUDATA.fields_by_name['velocity'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_IMUDATA.fields_by_name['acceleration'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_IMUDATA.fields_by_name['acceleration_sensor'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_IMUDATA.fields_by_name['rotation'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_IMUDATA.fields_by_name['rotational_velocity'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_IMUDATA.fields_by_name['rotational_velocity_sensor'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_IMUDATA.fields_by_name['orientation'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_IMUDATA.fields_by_name['orientation_rotvec'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_CENTREOFPRESSURE.fields_by_name['in_and_only_left_foot_cop'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_CENTREOFPRESSURE.fields_by_name['in_and_only_right_foot_cop'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_CENTREOFPRESSURE.fields_by_name['in_kinematic_chain_origin_cop'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3.fields_by_name['chestPose'].message_type = CommonTypes__pb2._POSE3D
_CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3.fields_by_name['edgelsInImage'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3.fields_by_name['edgelsInImageTop'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3.fields_by_name['orientation'].message_type = CommonTypes__pb2._DOUBLEVECTOR2
_CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3.containing_type = _CALIBRATIONDATACMC
_CALIBRATIONDATACMC.fields_by_name['calibrationData'].message_type = _CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3
_WHISTLEPERCEPT_WHISTLE.containing_type = _WHISTLEPERCEPT
_WHISTLEPERCEPT.fields_by_name['recognizedWhistles'].message_type = _WHISTLEPERCEPT_WHISTLE
_DEBUGMODIFY_MODIFYVALUE.containing_type = _DEBUGMODIFY
_DEBUGMODIFY.fields_by_name['valueMap'].message_type = _DEBUGMODIFY_MODIFYVALUE
_STEPBUFFER.fields_by_name['support_foot'].message_type = CommonTypes__pb2._POSE3D
_BODYAWARENESS.fields_by_name['calculatedCoM'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
_BODYAWARENESS.fields_by_name['currentCoMError'].message_type = CommonTypes__pb2._DOUBLEVECTOR3
DESCRIPTOR.message_types_by_name['CameraMatrix'] = _CAMERAMATRIX
DESCRIPTOR.message_types_by_name['BallPercept'] = _BALLPERCEPT
DESCRIPTOR.message_types_by_name['MultiBallPercept'] = _MULTIBALLPERCEPT
DESCRIPTOR.message_types_by_name['BallModel'] = _BALLMODEL
DESCRIPTOR.message_types_by_name['GoalPercept'] = _GOALPERCEPT
DESCRIPTOR.message_types_by_name['HeadMotionRequest'] = _HEADMOTIONREQUEST
DESCRIPTOR.message_types_by_name['StepControlRequest'] = _STEPCONTROLREQUEST
DESCRIPTOR.message_types_by_name['WalkRequest'] = _WALKREQUEST
DESCRIPTOR.message_types_by_name['KickRequest'] = _KICKREQUEST
DESCRIPTOR.message_types_by_name['GraspRequest'] = _GRASPREQUEST
DESCRIPTOR.message_types_by_name['ArmMotionRequest'] = _ARMMOTIONREQUEST
DESCRIPTOR.message_types_by_name['MotionRequest'] = _MOTIONREQUEST
DESCRIPTOR.message_types_by_name['LinePercept'] = _LINEPERCEPT
DESCRIPTOR.message_types_by_name['ShortLinePercept'] = _SHORTLINEPERCEPT
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['FieldPercept'] = _FIELDPERCEPT
DESCRIPTOR.message_types_by_name['RansacLinePercept'] = _RANSACLINEPERCEPT
DESCRIPTOR.message_types_by_name['RansacCirclePercept2018'] = _RANSACCIRCLEPERCEPT2018
DESCRIPTOR.message_types_by_name['ScanLineEndPoint'] = _SCANLINEENDPOINT
DESCRIPTOR.message_types_by_name['DoubleEdgel'] = _DOUBLEEDGEL
DESCRIPTOR.message_types_by_name['Edgel'] = _EDGEL
DESCRIPTOR.message_types_by_name['EdgelPair'] = _EDGELPAIR
DESCRIPTOR.message_types_by_name['ScanLineEdgelPercept'] = _SCANLINEEDGELPERCEPT
DESCRIPTOR.message_types_by_name['LineGraphPercept'] = _LINEGRAPHPERCEPT
DESCRIPTOR.message_types_by_name['StepControlStatus'] = _STEPCONTROLSTATUS
DESCRIPTOR.message_types_by_name['MotionStatus'] = _MOTIONSTATUS
DESCRIPTOR.message_types_by_name['OdometryData'] = _ODOMETRYDATA
DESCRIPTOR.message_types_by_name['BodyState'] = _BODYSTATE
DESCRIPTOR.message_types_by_name['BodyStatus'] = _BODYSTATUS
DESCRIPTOR.message_types_by_name['CalibrationData'] = _CALIBRATIONDATA
DESCRIPTOR.message_types_by_name['InertialModel'] = _INERTIALMODEL
DESCRIPTOR.message_types_by_name['CameraMatrixCalibration'] = _CAMERAMATRIXCALIBRATION
DESCRIPTOR.message_types_by_name['BallCandidates'] = _BALLCANDIDATES
DESCRIPTOR.message_types_by_name['RemoteControlCommand'] = _REMOTECONTROLCOMMAND
DESCRIPTOR.message_types_by_name['GroundContactModel'] = _GROUNDCONTACTMODEL
DESCRIPTOR.message_types_by_name['CollisionPercept'] = _COLLISIONPERCEPT
DESCRIPTOR.message_types_by_name['IMUData'] = _IMUDATA
DESCRIPTOR.message_types_by_name['CentreOfPressure'] = _CENTREOFPRESSURE
DESCRIPTOR.message_types_by_name['CalibrationDataCMC'] = _CALIBRATIONDATACMC
DESCRIPTOR.message_types_by_name['WhistlePercept'] = _WHISTLEPERCEPT
DESCRIPTOR.message_types_by_name['DebugModify'] = _DEBUGMODIFY
DESCRIPTOR.message_types_by_name['StepBuffer'] = _STEPBUFFER
DESCRIPTOR.message_types_by_name['bodyAwareness'] = _BODYAWARENESS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CameraMatrix = _reflection.GeneratedProtocolMessageType('CameraMatrix', (_message.Message,), dict(
  DESCRIPTOR = _CAMERAMATRIX,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.CameraMatrix)
  ))
_sym_db.RegisterMessage(CameraMatrix)

BallPercept = _reflection.GeneratedProtocolMessageType('BallPercept', (_message.Message,), dict(
  DESCRIPTOR = _BALLPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.BallPercept)
  ))
_sym_db.RegisterMessage(BallPercept)

MultiBallPercept = _reflection.GeneratedProtocolMessageType('MultiBallPercept', (_message.Message,), dict(

  BallPercept = _reflection.GeneratedProtocolMessageType('BallPercept', (_message.Message,), dict(
    DESCRIPTOR = _MULTIBALLPERCEPT_BALLPERCEPT,
    __module__ = 'Representations_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.MultiBallPercept.BallPercept)
    ))
  ,
  DESCRIPTOR = _MULTIBALLPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.MultiBallPercept)
  ))
_sym_db.RegisterMessage(MultiBallPercept)
_sym_db.RegisterMessage(MultiBallPercept.BallPercept)

BallModel = _reflection.GeneratedProtocolMessageType('BallModel', (_message.Message,), dict(
  DESCRIPTOR = _BALLMODEL,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.BallModel)
  ))
_sym_db.RegisterMessage(BallModel)

GoalPercept = _reflection.GeneratedProtocolMessageType('GoalPercept', (_message.Message,), dict(

  GoalPost = _reflection.GeneratedProtocolMessageType('GoalPost', (_message.Message,), dict(
    DESCRIPTOR = _GOALPERCEPT_GOALPOST,
    __module__ = 'Representations_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.GoalPercept.GoalPost)
    ))
  ,
  DESCRIPTOR = _GOALPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.GoalPercept)
  ))
_sym_db.RegisterMessage(GoalPercept)
_sym_db.RegisterMessage(GoalPercept.GoalPost)

HeadMotionRequest = _reflection.GeneratedProtocolMessageType('HeadMotionRequest', (_message.Message,), dict(
  DESCRIPTOR = _HEADMOTIONREQUEST,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.HeadMotionRequest)
  ))
_sym_db.RegisterMessage(HeadMotionRequest)

StepControlRequest = _reflection.GeneratedProtocolMessageType('StepControlRequest', (_message.Message,), dict(
  DESCRIPTOR = _STEPCONTROLREQUEST,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.StepControlRequest)
  ))
_sym_db.RegisterMessage(StepControlRequest)

WalkRequest = _reflection.GeneratedProtocolMessageType('WalkRequest', (_message.Message,), dict(
  DESCRIPTOR = _WALKREQUEST,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.WalkRequest)
  ))
_sym_db.RegisterMessage(WalkRequest)

KickRequest = _reflection.GeneratedProtocolMessageType('KickRequest', (_message.Message,), dict(
  DESCRIPTOR = _KICKREQUEST,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.KickRequest)
  ))
_sym_db.RegisterMessage(KickRequest)

GraspRequest = _reflection.GeneratedProtocolMessageType('GraspRequest', (_message.Message,), dict(
  DESCRIPTOR = _GRASPREQUEST,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.GraspRequest)
  ))
_sym_db.RegisterMessage(GraspRequest)

ArmMotionRequest = _reflection.GeneratedProtocolMessageType('ArmMotionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ARMMOTIONREQUEST,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.ArmMotionRequest)
  ))
_sym_db.RegisterMessage(ArmMotionRequest)

MotionRequest = _reflection.GeneratedProtocolMessageType('MotionRequest', (_message.Message,), dict(
  DESCRIPTOR = _MOTIONREQUEST,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.MotionRequest)
  ))
_sym_db.RegisterMessage(MotionRequest)

LinePercept = _reflection.GeneratedProtocolMessageType('LinePercept', (_message.Message,), dict(

  Intersection = _reflection.GeneratedProtocolMessageType('Intersection', (_message.Message,), dict(
    DESCRIPTOR = _LINEPERCEPT_INTERSECTION,
    __module__ = 'Representations_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.LinePercept.Intersection)
    ))
  ,

  FieldLineSegment = _reflection.GeneratedProtocolMessageType('FieldLineSegment', (_message.Message,), dict(
    DESCRIPTOR = _LINEPERCEPT_FIELDLINESEGMENT,
    __module__ = 'Representations_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.LinePercept.FieldLineSegment)
    ))
  ,
  DESCRIPTOR = _LINEPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.LinePercept)
  ))
_sym_db.RegisterMessage(LinePercept)
_sym_db.RegisterMessage(LinePercept.Intersection)
_sym_db.RegisterMessage(LinePercept.FieldLineSegment)

ShortLinePercept = _reflection.GeneratedProtocolMessageType('ShortLinePercept', (_message.Message,), dict(
  DESCRIPTOR = _SHORTLINEPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.ShortLinePercept)
  ))
_sym_db.RegisterMessage(ShortLinePercept)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), dict(
  DESCRIPTOR = _POLYGON,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.Polygon)
  ))
_sym_db.RegisterMessage(Polygon)

FieldPercept = _reflection.GeneratedProtocolMessageType('FieldPercept', (_message.Message,), dict(
  DESCRIPTOR = _FIELDPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.FieldPercept)
  ))
_sym_db.RegisterMessage(FieldPercept)

RansacLinePercept = _reflection.GeneratedProtocolMessageType('RansacLinePercept', (_message.Message,), dict(
  DESCRIPTOR = _RANSACLINEPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.RansacLinePercept)
  ))
_sym_db.RegisterMessage(RansacLinePercept)

RansacCirclePercept2018 = _reflection.GeneratedProtocolMessageType('RansacCirclePercept2018', (_message.Message,), dict(
  DESCRIPTOR = _RANSACCIRCLEPERCEPT2018,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.RansacCirclePercept2018)
  ))
_sym_db.RegisterMessage(RansacCirclePercept2018)

ScanLineEndPoint = _reflection.GeneratedProtocolMessageType('ScanLineEndPoint', (_message.Message,), dict(
  DESCRIPTOR = _SCANLINEENDPOINT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.ScanLineEndPoint)
  ))
_sym_db.RegisterMessage(ScanLineEndPoint)

DoubleEdgel = _reflection.GeneratedProtocolMessageType('DoubleEdgel', (_message.Message,), dict(
  DESCRIPTOR = _DOUBLEEDGEL,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.DoubleEdgel)
  ))
_sym_db.RegisterMessage(DoubleEdgel)

Edgel = _reflection.GeneratedProtocolMessageType('Edgel', (_message.Message,), dict(
  DESCRIPTOR = _EDGEL,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.Edgel)
  ))
_sym_db.RegisterMessage(Edgel)

EdgelPair = _reflection.GeneratedProtocolMessageType('EdgelPair', (_message.Message,), dict(
  DESCRIPTOR = _EDGELPAIR,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.EdgelPair)
  ))
_sym_db.RegisterMessage(EdgelPair)

ScanLineEdgelPercept = _reflection.GeneratedProtocolMessageType('ScanLineEdgelPercept', (_message.Message,), dict(
  DESCRIPTOR = _SCANLINEEDGELPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.ScanLineEdgelPercept)
  ))
_sym_db.RegisterMessage(ScanLineEdgelPercept)

LineGraphPercept = _reflection.GeneratedProtocolMessageType('LineGraphPercept', (_message.Message,), dict(
  DESCRIPTOR = _LINEGRAPHPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.LineGraphPercept)
  ))
_sym_db.RegisterMessage(LineGraphPercept)

StepControlStatus = _reflection.GeneratedProtocolMessageType('StepControlStatus', (_message.Message,), dict(
  DESCRIPTOR = _STEPCONTROLSTATUS,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.StepControlStatus)
  ))
_sym_db.RegisterMessage(StepControlStatus)

MotionStatus = _reflection.GeneratedProtocolMessageType('MotionStatus', (_message.Message,), dict(
  DESCRIPTOR = _MOTIONSTATUS,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.MotionStatus)
  ))
_sym_db.RegisterMessage(MotionStatus)

OdometryData = _reflection.GeneratedProtocolMessageType('OdometryData', (_message.Message,), dict(
  DESCRIPTOR = _ODOMETRYDATA,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.OdometryData)
  ))
_sym_db.RegisterMessage(OdometryData)

BodyState = _reflection.GeneratedProtocolMessageType('BodyState', (_message.Message,), dict(
  DESCRIPTOR = _BODYSTATE,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.BodyState)
  ))
_sym_db.RegisterMessage(BodyState)

BodyStatus = _reflection.GeneratedProtocolMessageType('BodyStatus', (_message.Message,), dict(
  DESCRIPTOR = _BODYSTATUS,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.BodyStatus)
  ))
_sym_db.RegisterMessage(BodyStatus)

CalibrationData = _reflection.GeneratedProtocolMessageType('CalibrationData', (_message.Message,), dict(
  DESCRIPTOR = _CALIBRATIONDATA,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.CalibrationData)
  ))
_sym_db.RegisterMessage(CalibrationData)

InertialModel = _reflection.GeneratedProtocolMessageType('InertialModel', (_message.Message,), dict(
  DESCRIPTOR = _INERTIALMODEL,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.InertialModel)
  ))
_sym_db.RegisterMessage(InertialModel)

CameraMatrixCalibration = _reflection.GeneratedProtocolMessageType('CameraMatrixCalibration', (_message.Message,), dict(
  DESCRIPTOR = _CAMERAMATRIXCALIBRATION,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.CameraMatrixCalibration)
  ))
_sym_db.RegisterMessage(CameraMatrixCalibration)

BallCandidates = _reflection.GeneratedProtocolMessageType('BallCandidates', (_message.Message,), dict(

  Patch = _reflection.GeneratedProtocolMessageType('Patch', (_message.Message,), dict(
    DESCRIPTOR = _BALLCANDIDATES_PATCH,
    __module__ = 'Representations_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.BallCandidates.Patch)
    ))
  ,
  DESCRIPTOR = _BALLCANDIDATES,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.BallCandidates)
  ))
_sym_db.RegisterMessage(BallCandidates)
_sym_db.RegisterMessage(BallCandidates.Patch)

RemoteControlCommand = _reflection.GeneratedProtocolMessageType('RemoteControlCommand', (_message.Message,), dict(
  DESCRIPTOR = _REMOTECONTROLCOMMAND,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.RemoteControlCommand)
  ))
_sym_db.RegisterMessage(RemoteControlCommand)

GroundContactModel = _reflection.GeneratedProtocolMessageType('GroundContactModel', (_message.Message,), dict(
  DESCRIPTOR = _GROUNDCONTACTMODEL,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.GroundContactModel)
  ))
_sym_db.RegisterMessage(GroundContactModel)

CollisionPercept = _reflection.GeneratedProtocolMessageType('CollisionPercept', (_message.Message,), dict(
  DESCRIPTOR = _COLLISIONPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.CollisionPercept)
  ))
_sym_db.RegisterMessage(CollisionPercept)

IMUData = _reflection.GeneratedProtocolMessageType('IMUData', (_message.Message,), dict(
  DESCRIPTOR = _IMUDATA,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.IMUData)
  ))
_sym_db.RegisterMessage(IMUData)

CentreOfPressure = _reflection.GeneratedProtocolMessageType('CentreOfPressure', (_message.Message,), dict(
  DESCRIPTOR = _CENTREOFPRESSURE,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.CentreOfPressure)
  ))
_sym_db.RegisterMessage(CentreOfPressure)

CalibrationDataCMC = _reflection.GeneratedProtocolMessageType('CalibrationDataCMC', (_message.Message,), dict(

  CalibrationDataSampleV3 = _reflection.GeneratedProtocolMessageType('CalibrationDataSampleV3', (_message.Message,), dict(
    DESCRIPTOR = _CALIBRATIONDATACMC_CALIBRATIONDATASAMPLEV3,
    __module__ = 'Representations_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.CalibrationDataCMC.CalibrationDataSampleV3)
    ))
  ,
  DESCRIPTOR = _CALIBRATIONDATACMC,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.CalibrationDataCMC)
  ))
_sym_db.RegisterMessage(CalibrationDataCMC)
_sym_db.RegisterMessage(CalibrationDataCMC.CalibrationDataSampleV3)

WhistlePercept = _reflection.GeneratedProtocolMessageType('WhistlePercept', (_message.Message,), dict(

  Whistle = _reflection.GeneratedProtocolMessageType('Whistle', (_message.Message,), dict(
    DESCRIPTOR = _WHISTLEPERCEPT_WHISTLE,
    __module__ = 'Representations_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.WhistlePercept.Whistle)
    ))
  ,
  DESCRIPTOR = _WHISTLEPERCEPT,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.WhistlePercept)
  ))
_sym_db.RegisterMessage(WhistlePercept)
_sym_db.RegisterMessage(WhistlePercept.Whistle)

DebugModify = _reflection.GeneratedProtocolMessageType('DebugModify', (_message.Message,), dict(

  ModifyValue = _reflection.GeneratedProtocolMessageType('ModifyValue', (_message.Message,), dict(
    DESCRIPTOR = _DEBUGMODIFY_MODIFYVALUE,
    __module__ = 'Representations_pb2'
    # @@protoc_insertion_point(class_scope:naothmessages.DebugModify.ModifyValue)
    ))
  ,
  DESCRIPTOR = _DEBUGMODIFY,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.DebugModify)
  ))
_sym_db.RegisterMessage(DebugModify)
_sym_db.RegisterMessage(DebugModify.ModifyValue)

StepBuffer = _reflection.GeneratedProtocolMessageType('StepBuffer', (_message.Message,), dict(
  DESCRIPTOR = _STEPBUFFER,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.StepBuffer)
  ))
_sym_db.RegisterMessage(StepBuffer)

bodyAwareness = _reflection.GeneratedProtocolMessageType('bodyAwareness', (_message.Message,), dict(
  DESCRIPTOR = _BODYAWARENESS,
  __module__ = 'Representations_pb2'
  # @@protoc_insertion_point(class_scope:naothmessages.bodyAwareness)
  ))
_sym_db.RegisterMessage(bodyAwareness)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\031de.naoth.rc.core.messages'))
_BALLMODEL.fields_by_name['futurePosition'].has_options = True
_BALLMODEL.fields_by_name['futurePosition']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CAMERAMATRIXCALIBRATION.fields_by_name['correctionOffset'].has_options = True
_CAMERAMATRIXCALIBRATION.fields_by_name['correctionOffset']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
# @@protoc_insertion_point(module_scope)
